@@ -12,10 +12,10 @@ from __future__ import division, print_function
 from gettext import gettext as _
 import logging
 
-from gi.repository import Gtk
-from gi.repository import Gdk
-from gi.repository import GObject
-from gi.repository import Pango
+from lib.gibindings import Gtk
+from lib.gibindings import Gdk
+from lib.gibindings import GObject
+from lib.gibindings import Pango
 
 import lib.xml
 from . import widgets
@@ -209,7 +209,7 @@ class ButtonMapping (object):
             # Exclude possible bindings whose modifiers do not overlap
             if (modifiers & possible) != modifiers:
                 continue
-            # Include only exact matches, and those possibilies which can be
+            # Include only exact matches, and those possibilities which can be
             # reached by pressing more modifier keys.
             if modifiers == possible or ~modifiers & possible:
                 possibilities.append((possible, btn, action))
